@@ -32,6 +32,7 @@ __all__ = (
     "DocDbSettingsTypeDef",
     "DynamoDbSettingsTypeDef",
     "ElasticsearchSettingsTypeDef",
+    "EndpointSettingTypeDef",
     "EndpointTypeDef",
     "EventCategoryGroupTypeDef",
     "EventSubscriptionTypeDef",
@@ -85,6 +86,7 @@ __all__ = (
     "DescribeApplicableIndividualAssessmentsResponseTypeDef",
     "DescribeCertificatesResponseTypeDef",
     "DescribeConnectionsResponseTypeDef",
+    "DescribeEndpointSettingsResponseTypeDef",
     "DescribeEndpointTypesResponseTypeDef",
     "DescribeEndpointsResponseTypeDef",
     "DescribeEventCategoriesResponseTypeDef",
@@ -200,6 +202,21 @@ class ElasticsearchSettingsTypeDef(
     pass
 
 
+EndpointSettingTypeDef = TypedDict(
+    "EndpointSettingTypeDef",
+    {
+        "Name": str,
+        "Type": Literal["string", "boolean", "integer", "enum"],
+        "EnumValues": List[str],
+        "Sensitive": bool,
+        "Units": str,
+        "Applicability": str,
+        "IntValueMin": int,
+        "IntValueMax": int,
+    },
+    total=False,
+)
+
 EndpointTypeDef = TypedDict(
     "EndpointTypeDef",
     {
@@ -302,6 +319,15 @@ KafkaSettingsTypeDef = TypedDict(
         "IncludeControlDetails": bool,
         "MessageMaxBytes": int,
         "IncludeNullAndEmpty": bool,
+        "SecurityProtocol": Literal[
+            "plaintext", "ssl-authentication", "ssl-encryption", "sasl-ssl"
+        ],
+        "SslClientCertificateArn": str,
+        "SslClientKeyArn": str,
+        "SslClientKeyPassword": str,
+        "SslCaCertificateArn": str,
+        "SaslUsername": str,
+        "SaslPassword": str,
     },
     total=False,
 )
@@ -330,6 +356,7 @@ MicrosoftSQLServerSettingsTypeDef = TypedDict(
         "DatabaseName": str,
         "ControlTablesFileGroup": str,
         "Password": str,
+        "QuerySingleAlwaysOnNode": bool,
         "ReadBackupOnly": bool,
         "SafeguardPolicy": Literal[
             "rely-on-sql-server-replication-agent",
@@ -339,6 +366,7 @@ MicrosoftSQLServerSettingsTypeDef = TypedDict(
         "ServerName": str,
         "Username": str,
         "UseBcpFullLoad": bool,
+        "UseThirdPartyBackupDevice": bool,
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
     },
@@ -370,6 +398,7 @@ MySQLSettingsTypeDef = TypedDict(
     "MySQLSettingsTypeDef",
     {
         "AfterConnectScript": str,
+        "CleanSourceMetadataOnMismatch": bool,
         "DatabaseName": str,
         "EventsPollInterval": int,
         "TargetDbType": Literal["specific-database", "multiple-databases"],
@@ -438,6 +467,7 @@ OracleSettingsTypeDef = TypedDict(
         "SecurityDbEncryption": str,
         "SecurityDbEncryptionName": str,
         "ServerName": str,
+        "SpatialDataOptionToGeoJsonFunctionName": str,
         "Username": str,
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
@@ -914,6 +944,12 @@ DescribeConnectionsResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeEndpointSettingsResponseTypeDef = TypedDict(
+    "DescribeEndpointSettingsResponseTypeDef",
+    {"Marker": str, "EndpointSettings": List["EndpointSettingTypeDef"]},
+    total=False,
+)
+
 DescribeEndpointTypesResponseTypeDef = TypedDict(
     "DescribeEndpointTypesResponseTypeDef",
     {"Marker": str, "SupportedEndpointTypes": List["SupportedEndpointTypeTypeDef"]},
